@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.CodeStar 1.17.61\n"
-        "Version:         1.17.61.1\n"
-        "Builder version: 4.8.1\n"
+        "Type annotations for boto3.CodeStar 1.17.77\n"
+        "Version:         1.17.77\n"
+        "Builder version: 4.13.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-codestar/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codestar.html#CodeStar\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/codestar.html#CodeStar\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.61.1")
+    print("1.17.77")
 
 
 def main() -> None:
